<?php
/**
 * Administration settings for WP-SimplyHired API
 *
 * @package WP_SimplyHired_API
 */

add_action('admin_menu', 'wpsha_add_settings_page' );
add_action('admin_menu', 'wpsha_admin_styles' );
/*
 * Add settings page to admin area
 *
 */
function wpsha_add_settings_page() {

//$page = 

	$page = add_plugins_page(__('SimplyHired API for WordPress', 'wp_simplyhired_api'), __('SimplyHired API', 'wp_simplyhired_api'), 8, __FILE__, 'wpsha_settings_page');
	add_action( 'admin_print_styles-' . $page, 'wpsha_admin_styles' );
	wp_register_style( 'wpsha_plugin_stylesheet', WPSHA_URL . '/css/admin.css' );
}

/*
 * Enqueue admin stylesheet
 *
 */
function wpsha_admin_styles() {
	wp_enqueue_style('wpsha_admin_stylesheet', WPSHA_URL . '/css/admin.css');
}

/*
 * Enqueue admin javascript
 *
 */
function wpsha_admin_scripts() {
	wp_enqueue_script('sh_plugin_javascript', $shpluginscript, array('jquery'));
}

/**
 * Returns an array of all the settings defaults
 */
function wpsha_default_settings_args() {
	$defaults_arr = array(
		'publisher_id' 		=> '',
		'jobboard_url' 		=> '',
		'post_job_cost' 		=> '',
		'post_job_days' 		=> '',
		'base_page'			=> 'jobs',
		'show_backfill'		=> true,
		'broad_onet_code'		=> '',
		'plugin_attribution' 	=> true,
		'disable_tracking'	=> false,
		'is_usa'				=> true,
	);
	return $defaults_arr;
}

/**
 * Handles the main plugin settings
 *
 */
function wpsha_settings_page() {

	/*
	* Main settings variables
	*/
	$plugin_name = __('WP-SimplyHired API', 'wp_simplyhired_api');
	$settings_page_title = __('WP-SimplyHired API Settings', 'wp_simplyhired_api');
	$hidden_field_name = 'wp_simplyhired_api_submit_hidden';
	$plugin_data = get_plugin_data( WPSHA_DIR . '/wp-simplyhired.php');

	/*
	* Grabs the default plugin settings
	*/
	$defaults_arr = wpsha_default_settings_args();

	/*
	* Add a new option to the database
	*/
	add_option( 'wp_simplyhired_api_settings', $defaults_arr );

	/*
	* Set form data IDs the same as settings keys
	* Loop through each
	*/
	$settings_keys = array_keys( $defaults_arr );
	foreach ( $settings_keys as $key ) :
		$data[$key] = $key;
	endforeach;

	/*
	* Get existing options from database
	*/
	$settings = get_option( 'wp_simplyhired_api_settings' );
	foreach ( $defaults_arr as $key => $value ) {
		// Handles new default options added after initial release
		if( !array_key_exists ( $key, $settings )) {
			$val[$key] = $defaults_arr[$key];
		}
		else {
			$val[$key] = $settings[$key];
		}
	}
	?>
	<div class="wrap">
		<div class="icon32" id="icon-plugins"><br></div>
		<h2><?php echo $settings_page_title; ?></h2>
		<p><?php echo $plugin_data['Description']; ?></p>
	<?php
	/*
	* If any information has been posted, we need
	* to update the options in the database
	*/
	if ( $_POST[$hidden_field_name] == 'Y' ) :
		/*
		* Loops through each option and sets it if needed
		*/
		foreach ( $defaults_arr as $key => $value ) :
			$settings[$key] = $val[$key] = $_POST[$data[$key]];
		endforeach;

		/*
		* Update plugin settings
		*/
		update_option( 'wp_simplyhired_api_settings', $settings );

		/*
		* Display updated message and test XML link
		*/
		global $wpsha;
		$wpsha->set_onet( $settings[ 'broad_onet_code'] );
		$wpsha->search();
		?>
		<div class="updated" style="margin: 15px 0;">
			<p><strong><?php _e('Settings saved.', 'wp_simplyhired_api'); ?></strong>. <?php _e('You should test the XML response from the API after an update to settings.',$textdomain);?><?php $wpsha->print_apicall(true); ?></p>
		</div>
	<?php
	endif;
?>

		<div id="poststuff">

			<form name="form0" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI'] ); ?>" style="border:none;background:transparent;">

				<?php require_once( WPSHA_DIR . '/settings-admin-page.php' ); ?>

				<p class="submit" style="clear:both;">
					<input type="submit" name="Submit"  class="button-primary" value="<?php _e('Save Changes', 'wp_simplyhired_api') ?>" />
					<input type="hidden" name="<?php echo $hidden_field_name; ?>" value="Y" />
				</p>

			</form>
		</div>
	</div>
<?php
}



?>