<?php
/**
 * SimplyHired Jobs Widget
 *
 * @package WP_SimplyHired_API
 * @subpackage Widgets
 */


/**
 * Output of the widget.
 */
class WP_SimplyHired_API_Widget_Jobs extends WP_Widget {

	var $prefix = 'wpsha';
	var $textdomain = 'wp_simplyhired_api';

	function WP_SimplyHired_API_Widget_Jobs() {
		$widget_ops = array( 'classname' => 'jobs', 'description' => __( 'An advanced widget that gives you total control over the output of your SimplyHired Job widget.', $this->textdomain) );
		$control_ops = array( 'width' => 540, 'height' => 350, 'id_base' => "{$this->prefix}-jobs" );
		$this->WP_Widget( "{$this->prefix}-jobs", __( 'SimplyHired Jobs', $this->textdomain), $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {
		global $wpsha;

		extract( $args );

		$args = array();

		$args['query'] = $instance['query'];
		$args['location'] = $instance['location'];
		$args['number'] = intval( $instance['number'] );
		$args['sort_order'] = $instance['sort_order'];
		/* Post a job button */
		$args['show_post_button'] = $instance['show_post_button'];
		$args['link_before'] = $instance['link_before'];
		$args['link_after'] = $instance['link_after'];
		$args['date_format'] = $instance['date_format'];
		$args['show_date'] = $instance['show_date'];
		$args['title_li'] = false;
		$args['echo'] = false;

		/* Open the output of the widget. */
		echo $before_widget;

		/* If there is a title given, add it along with the $before_title and $after_title variables. */
		if ( $instance['title'] )
			echo $before_title . apply_filters( 'widget_title',  $instance['title'], $instance, $this->id_base ) . $after_title;

		/* Grab a list of jobs. */
		$widgetJobs = new WP_SimplyHired_API();
		$widgetJobs->set_query( $args['query'] );
		$widgetJobs->set_location( $args['location'] );
		//$shJobs->set_radius( $args['radius'] );
		$results = $widgetJobs->search( $args['number'] );
		//var_dump($results);
		
		/* Output the page list. */
		echo '<ul class="wpsha-widget-joblist">';
		foreach ( $results->rs->r as $result ) {
			$anchor = 'href="'.$result->src['url'].'" target="_blank" rel="nofollow" onMouseDown="xml_sclk(this);"';
			echo '
			<li class="job-item">
				<a ' . $anchor . '>' . $result->jt . '</a>
				<div class="meta">' . 
					$result->cn . ' - ' . $result->loc . 
				'</div>
			</li>
			';
		}
		echo '</ul>';
		
		/* Get settings for the Job Posting rate & days */
		$settings = get_option( 'wp_simplyhired_api_settings' );
		$posting_cost = $settings['post_job_cost'];
		$posting_days = $settings['post_job_days'];
		$jobboard_url = $settings['jobboard_url'];
		
		/* Display the Post Job button */
		echo '<div class="post-job"><a href="http://' . $jobboard_url . '/a/jbb/post-job" class="button">Post a Job</a>
			Just $' . $posting_cost . ' for ' . $posting_days . ' days!</div>';
		
		echo '<div class="attribution">';
			if ( $settings['plugin_attribution'] ) {
				echo '<div class="wpsha-attribution"><a href="http://webstractions.com/wordpress-plugins/wp-simplyhired-api">Get this widget</div>';
			}
			/* Per SimplyHired terms, show attribution */
			echo '<div class="sh-attribution">';
				$wpsha->print_attribution();
			echo '</div>';
		echo '</div>';

		/* Print output of widget to screen */
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Set the instance to the new instance. */
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['query'] = strip_tags( $new_instance['query'] );
		$instance['location'] = strip_tags( $new_instance['location'] );
		$instance['number'] = strip_tags( $new_instance['number'] );
		$instance['sort_order'] = $new_instance['sort_order'];
		/* Post a job button */
		$instance['show_post_button'] = strip_tags( $new_instance['show_post_button'] );

		$instance['date_format'] = strip_tags( $new_instance['date_format'] );
		$instance['link_before'] = $new_instance['link_before'];
		$instance['link_after'] = $new_instance['link_after'];

		$instance['show_date'] = ( isset( $new_instance['show_date'] ) ? 1 : 0 );

		return $instance;
	}

	function form( $instance ) {

		//Defaults
		$defaults = array(
			'title' => __( 'Latest Jobs', $this->textdomain),
			'query' => '',
			'location' => '',
			'number' => 5,
			'sort_order' => 'date',
			'show_post_button' => true,
			'show_date' => false,
			'date_format' => get_option( 'date_format' ),
			'link_before' => '',
			'link_after' => '',
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

		$sort_order = array( 'date' => __( 'Date', $this->textdomain ), 'Relevance' => __( 'Relevance', $this->textdomain ) );
		$show_date = array( '' => '', 'created' => __( 'Created', $this->textdomain ), 'modified' => __( 'Modified', $this->textdomain ) );
		?>

		<div class="wpsha-widget-controls columns-2">
		<?php $this->print_text_input( $this->get_field_id('title'), $this->get_field_name('title'), $instance['title'], 'title' ); ?>

		<?php $this->print_text_input( $this->get_field_id('query'), $this->get_field_name('query'), $instance['query'], 'query' ); ?>
		
		<?php $this->print_text_input( $this->get_field_id('location'), $this->get_field_name('location'), $instance['location'], 'location' ); ?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'sort_order' ); ?>"><code>sort_order</code></label> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'sort_order' ); ?>" name="<?php echo $this->get_field_name( 'sort_order' ); ?>">
				<?php foreach ( $sort_order as $option_value => $option_label ) { ?>
					<option value="<?php echo $option_value; ?>" <?php selected( $instance['sort_order'], $option_value ); ?>><?php echo $option_label; ?></option>
				<?php } ?>
			</select>
		</p>
		
		<?php $this->print_text_input( $this->get_field_id('number'), $this->get_field_name('number'), $instance['number'], 'number' ); ?>
		</div>

		<div class="wpsha-widget-controls columns-2 column-last">

		<?php $this->print_text_input( $this->get_field_id('link_before'), $this->get_field_name('link_before'), $instance['link_before'], 'link_before'  ); ?>
		
		<?php $this->print_text_input( $this->get_field_id('link_after'), $this->get_field_name('link_after'), $instance['link_after'], 'link_after' ); ?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><code>show_date</code></label> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>">
				<?php foreach ( $show_date as $option_value => $option_label ) { ?>
					<option value="<?php echo $option_value; ?>" <?php selected( $instance['show_date'], $option_value ); ?>><?php echo $option_label; ?></option>
				<?php } ?>
			</select>
		</p>
		
		<?php $this->print_text_input( $this->get_field_id('date_format'), $this->get_field_name('date_format'), $instance['date_format'], 'date_format' ); ?>
		
		<p>
			<input type="checkbox" id="<?php echo $this->get_field_id( 'show_post_button' ); ?>" name="<?php echo $this->get_field_name( 'show_post_button' ); ?>" <?php if ( $instance['show_post_button'] ) echo 'checked="checked" value="true"'; ?> />
			<label for="<?php echo $this->get_field_id( 'show_post_button' ); ?>"><?php _e( 'Show post a job button?', $textdomain ); ?></label> 
		</p>
		
		</div>
		
		<div style="clear:both;">&nbsp;</div>
	<?php
	}
	
	/*
	 * Helper function to print form text input element to screen
	 *
	 */
	function print_text_input( $field_id, $field_name, $field_value, $field_key=null ) {
	
	if( !isset($field_key) ) 
		$field_key=$fieldname;

	$html = '
		<p>
			<label for="' . $field_id . '"><code>' . $field_key . '</code></label>
			<input type="text" class="widefat code" id="' . $field_id . '" name="' . $field_name . '" value="' . $field_value . '" />
		</p>
	';
	echo $html;
	}
}

?>