<?php
/*
Plugin Name: WP-SimplyHired API
Plugin URI: http://webstractions.com/wordpress-plugins/wp-simplyhired-api
Version: 0.3.1

Description: A Plugin that provides tools to utilize the simplyhired.com web services API for Job-a-matic niche job boards. Host your own job board powered by SimplyHired API. This plugin allows users to search for jobs, browse jobs by location or by category, track pay-per-click jobs and link directly to each job. You will need to register and obtain a <a href="http://jobamatic.com">Job-a-matic account</a> in order to use this Plugin.

Author: Webstractions Web Development
Author URI: http://webstractions.com

Copyright 2011 Webstractions.com
*/

/*
	License: GPL2
	This script is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 3 of the License, or
	(at your option) any later version.

	This script is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*Constants*/
define( WPSHA_DIR, dirname( __FILE__ ) );
define( WPSHA_URL, WP_PLUGIN_URL . '/' . str_replace(basename( __FILE__),"",plugin_basename(__FILE__)) );

/* This plugin class extends the SimplyHired_API class wrapper */
require_once ( WPSHA_DIR . '/classes/simplyhired-api.class.php');

/**
 * Main plugin class
 */
class WP_SimplyHired_API extends SimplyHired_API {


	/* Plugin Options */
	public $options = array();
	
	/**      
	 * actions for plugin initialization
	 */
	function __construct() {
		
		if( is_feed() ) return;
		
		/* Constants */
		$plugin_dir = basename(dirname(__FILE__));
		$this->theme_dir = get_bloginfo( 'template_url' );
		$this->theme_path = get_theme_root().'/'.get_template();
	
		/* Language */
		load_plugin_textdomain( 'wp_simplyhired_api', 'wp-content/plugins/' . $plugin_dir, $plugin_dir );
		
		/* Options */
		$this->options = get_option('wp_simplyhired_api_settings');
		
		/* Include files */
		$this->include_files();
		
		/* Actions */
		$this->actions();
		
		/* Plugin requires a Job-a-matic account */
		if ( 	isset( $this->options['publisher_id'] ) 
			&& 	isset( $this->options['jobboard_url'] ) 
			&& !is_feed() ) {
			/* Initialize SimplyHired API */
			$this->init( $this->options['publisher_id'], $this->options['jobboard_url'] );
			
			/* Set broad ONET code (can be over-ridden via shortcode ) */
			if ( $this->options['broad_onet_code'] ) {
				$this->set_onet($this->options['broad_onet_code']);
			}
			$this->set_is_usa( $this->options['is_usa'] );
			$this->set_disable_tracking( $this->options['disable_tracking']);
		}
	}
	
	/*
	 * Required files to include
	 *
	 */
	function include_files() {
		
		require_once( WPSHA_DIR . '/data/data.php' ); 
		require_once( WPSHA_DIR . '/shortcodes.php' ); 
		
		/* Admin files to include */
		if( is_admin() ) {
			require_once ( WPSHA_DIR . '/settings-admin.php');
			//require_once ( WPSHA_DIR . '/editor-functions.php' );
		}
	
	}

	/*
	 *
	 *
	 */
	 function actions() {
		/* Actions */
		add_action('generate_rewrite_rules', 
			array('WP_SimplyHired_API', 'add_rewrite_rules'));
		add_action('init', 
			array('WP_SimplyHired_API', 'flush_rewrite'));
		add_action( 'widgets_init', 
			array('WP_SimplyHired_API', 'register_widgets') );

		/* Non-admin actions only */
		if ( !is_admin() ) { 
			add_action('wp_print_styles', 
				array ( 'WP_SimplyHired_API' , 'wpsha_print_styles' ) );
			if( !$this->options['disable_tracking'] == 'true' ) {
				add_action( 'wp_footer', 
					array ( 'WP_SimplyHired_API' , 'print_footer_scripts' ) , 11 );
			}
		}
	}
	/**      
	 * Flush rewrite rules to accept plugin-specific ones
	 * This also runs on plugin deactivation to remove plugin-specific rules
	 */
	function flush_rewrite() {
		global $wp_rewrite;
		$wp_rewrite->flush_rules();
	}
	
	/**      
	 * Generate plugin-specific rewrite rules
	 */
	function add_rewrite_rules( $wp_rewrite ) {

		$options = get_option('wp_simplyhired_api_settings');
		$base_page = $options['base_page'];
		
		$job_paged_rules = array( $base_page."/page/(.+)" => "index.php?pagename=$base_page&page=" . $wp_rewrite->preg_index(1) );
		//$job_feed_rules = array( $base_page.'/feed' => 'index.php?pagename=$base_page&feed=jobs' );

		// add these rules to the WP rewrite rules, more specific ones followed by more general ones
		//$wp_rewrite->rules = $job_paged_rules + $job_feed_rules + $wp_rewrite->rules;
		$wp_rewrite->rules = $job_paged_rules + $wp_rewrite->rules;
	}
	
	/*
	 * Gets the Html to handle pagination 
	 *
	 * @var $results - uses response for search (rq)
	 */
	function get_pagination_html( $results ) {
		global $wp;
		
		if ( $results->error  ) 
			return; // no need for pagination on error
		
		$response = $results->rq;

		$numPages = (int) ( $response->tv / $response->rpd )+1;
		if( $response->tv >= 1000 ) $numPages--;
		if( $numPages <= 1 )
			return; // no need for pagination
		
		$queryVars = $wp->query_vars;
		$curPage = isset( $queryVars[ 'page' ] ) ? (int) $queryVars[ 'page' ] : 1;
		
		// page bounds
		$scope = 3;
		$start = $curPage - $scope;
		$end = $curPage + $scope;

		// if we can't satisfy the scope (add enough pages) on one side,
		// add pages to the other side
		if( $start <= 1 ) {
			$end += ( 1 - $start );
			$start = 2;
		}
		else if( $end >= $numPages ) {
			$start -= ( $end - $numPages );
			$end = $numPages - 1;
		}
		
		// limit the start and end to their extreme values
		$start = max( $start, 2 );
		$end = min( $end, $numPages - 1 );

		$pagesToLinkTo = array( 1 );
		for( $page = $start; $page <= $end; $page++ )
			$pagesToLinkTo[] = $page;
		$pagesToLinkTo[] = $numPages;

		$html = '
		<div id="pagination">
			<div class="pagelist">
			  <label></label>';
		
		$base_uri = get_bloginfo( 'home' ) . '/' . $this->options['base_page'];
		
		//if( $queryVars['trade'] )
		//	$base_uri .= '/trade/' . $queryVars['trade'];
		//if( $queryVars['location'] )
		//	$base_uri .= '/location/' . $queryVars['location'];
		
		$base_uri .= '/page/';

		$prevPage = $pagesToLinkTo[0];
		foreach( $pagesToLinkTo as $page ) {
			if( $page-$prevPage > 1 ) // skipped a few pages
			$html .= '<span>...</span>'; // add a spacer
			$current_class = ( $page == $curPage ) ? ' class="current"' : '';
			// echo the link
			$html .= '<a href="' . $base_uri . $page . '"' . $current_class . '>' . $page . '</a>';
			$prevPage = $page;
		}
		
		$html .= '	
			</div>
		</div>';
		
		return $html;
	}
	
	/*
	 * Gets the Html to dispay attributions for the plugin & SimplyHired
	 *
	 */
	function get_attribution_html() {
		$html = '<div class="attribution">';
			/* Show attribution for plugin if allowed */
			if ( $this->options['plugin_attribution'] ) {
				$html .= '<div class="wpsha-attribution"><a href="http://webstractions.com/wordpress-plugins/wp-simplyhired-api">' . __( 'Powered by WP Jobs Plugin', $this->textdomain ) . '</div>';
			}
			/* Per SimplyHired terms, show attribution */
			$html .= '<div class="sh-attribution">';
			$html .=	$this->print_attribution(false);
			$html .= '</div>';
		$html .= '</div>';
		return $html;
	}
	
	/*
	 * Register widgets
	 *
	 */
	function register_widgets() {
		
		/* Load widget file. */
		require_once( WPSHA_DIR . '/widget-simplyhired-jobs.php' );

		/* Register widget. */
		register_widget( 'WP_SimplyHired_API_Widget_Jobs' );
	}
	
	/*
	 * Enqueue the stylesheet
	 *
	 * @TODO: Add an over-ride in admin area for custom theme styling
	 */
	function wpsha_print_styles() {
		wp_enqueue_style('wpsha-stylesheet', WPSHA_URL . 'css/styles.css', false, 0.2, 'screen' );
	}

}

/* 
 * Load the main plugin class and setup global
 *
 * @global $wpsha
 */
if ( class_exists( 'WP_SimplyHired_API' ) ) {
	$wpsha = new WP_SimplyHired_API();
}
?>